@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.34_001';
+our $VERSION = '0.34_002';
 
 use Carp;
 
@@ -378,6 +378,22 @@ sub import_into
    }
 }
 
+if( !defined &Future::AWAIT_CLONE ) {
+   # TODO: These ought to be implemented by Future.pm itself, and it can do
+   # these in a faster, more performant way
+   *Future::AWAIT_CLONE    = sub { shift->new };
+   *Future::AWAIT_NEW_DONE = *Future::AWAIT_DONE = sub { shift->done( @_ ) };
+   *Future::AWAIT_NEW_FAIL = *Future::AWAIT_FAIL = sub { shift->fail( @_ ) };
+
+   *Future::AWAIT_IS_READY     = sub { shift->is_ready };
+   *Future::AWAIT_IS_CANCELLED = sub { shift->is_cancelled };
+
+   *Future::AWAIT_ON_READY  = sub { shift->on_ready( @_ ) };
+   *Future::AWAIT_ON_CANCEL = sub { shift->on_cancel( @_ ) };
+
+   *Future::AWAIT_GET = sub { shift->get };
+}
+
 =head1 SEE ALSO
 
 =over 4
