@@ -8,7 +8,7 @@ package Future::AsyncAwait::Awaitable;
 use strict;
 use warnings;
 
-our $VERSION = '0.34_001';
+our $VERSION = '0.34_002';
 
 =head1 NAME
 
@@ -23,105 +23,128 @@ is largely of relevance to implementors of other module integrations, event
 systems, or similar. It is not necessary to make regular use of the syntax
 provided by the module when working with existing event systems.
 
+The methods required by this interface are all capitalised and prefixed with
+C<AWAIT_...>, ensuring they are unlikely to clash with existing methods on a
+class which may have differing semantics.
+
+=head2 Role::Tiny
+
+If L<Role::Tiny> is available, this module declares itself to be a role that
+requires the following named methods. The role supplies no code to the applied
+class, but can be useful for checking that you have in fact implemented all of
+the required methods.
+
 =cut
 
+if( defined eval { require Role::Tiny } ) {
+   Role::Tiny->import;
+
+   requires( qw(
+      AWAIT_CLONE AWAIT_NEW_DONE AWAIT_NEW_FAIL
+
+      AWAIT_DONE AWAIT_FAIL AWAIT_GET
+      AWAIT_IS_READY AWAIT_ON_READY
+      AWAIT_IS_CANCELLED AWAIT_ON_CANCEL
+   ) );
+}
+
 =head1 CONSTRUCTORS
 
 The following methods are expected to create new future instances. They make
 use of the class set by the prevailing C<future_class> import argument, if
 set, or default to C<Future> if not.
 
-=head2 done
+=head2 AWAIT_NEW_DONE
 
 Generate a new immediate future that is successful. The future will already be
 ready and have the list of values set as its result.
 
-   $f = $CLASS->done( @results )
+   $f = $CLASS->AWAIT_NEW_DONE( @results )
 
-   # $f->is_ready will be true
-   # $f->get will return @results
+   # $f->AWAIT_IS_READY will be true
+   # $f->AWAIT_GET will return @results
 
-=head2 fail
+=head2 AWAIT_NEW_FAIL
 
 Generate a new immediate future that is failed. The future will already be
-ready and invoking the L</get> method will throw the given exception.
+ready and invoking the L</AWAIT_GET> method will throw the given exception.
 
-   $f = $CLASS->fail( $message )
+   $f = $CLASS->AWAIT_NEW_FAIL( $message )
 
-   # $f->is_ready will be true
-   # $f->get will throw $message
+   # $f->AWAIT_IS_READY will be true
+   # $f->AWAIT_GET will throw $message
 
 =head1 INSTANCE METHODS
 
-=head2 new
+=head2 AWAIT_CLONE
 
 Generate a new pending future of the same type as an existing one, which is
 not modified by doing so.
 
-   $new_f = $f->new
+   $new_f = $f->AWAIT_CLONE
 
 If the instance has any fields that are required for successful operation
 (such as application-wide context or event system components) these ought to
 be copied. The method should not 
 
-=head2 done
+=head2 AWAIT_DONE
 
 Sets the success result of an existing still-pending future. It will only be
 invoked on future instances that are currently pending.
 
-   $f->done( @results )
+   $f->AWAIT_DONE( @results )
 
-   # $f->is_ready will now be true
-   # $f->get will now return @results
+   # $f->AWAIT_IS_READY will now be true
+   # $f->AWAIT_GET will now return @results
 
-=head2 fail
+=head2 AWAIT_FAIL
 
 Sets the failure result of an existing still-pending future. It will only be
 invoked on future instances that are currently pending.
 
-   $f->fail( $message )
+   $f->AWAIT_FAIL( $message )
 
-   # $f->is_ready will now be true
-   # $f->get will now throw $message
+   # $f->AWAIT_IS_READY will now be true
+   # $f->AWAIT_GET will now throw $message
 
-=head2 is_ready
+=head2 AWAIT_IS_READY
 
 Returns true if a future is ready (successful, failed or cancelled); false if
 still pending.
 
-   $bool = $f->is_ready
+   $bool = $f->AWAIT_IS_READY
 
-=head2 is_cancelled
+=head2 AWAIT_IS_CANCELLED
 
 Returns true is a future has already been cancelled; false if still pending,
 successful or failed.
 
-   $bool = $f->is_cancelled
+   $bool = $f->AWAIT_IS_CANCELLED
 
-=head2 get
+=head2 AWAIT_GET
 
 Yields the result of a successful future (or just the first value if called in
 scalar context). Throws the failure message as an exception if called on a a
 failed one. Will not be invoked on a pending or cancelled future.
 
-   @result = $f->get
-   $result = $f->get
-   $f->get
+   @result = $f->AWAIT_GET
+   $result = $f->AWAIT_GET
+   $f->AWAIT_GET
 
-=head2 on_ready
+=head2 AWAIT_ON_READY
 
 Attach a new CODE reference to be invoked when the future becomes ready (by
 success or failure). The arguments and context that C<$code> is invoked with
 are unspecified.
 
-   $f->on_ready( $code )
+   $f->AWAIT_ON_READY( $code )
 
-=head2 on_cancel
+=head2 AWAIT_ON_CANCEL
 
 Attach a new CODE reference to be invoked when the future is cancelled. The
 arguments and context that C<$code> is invoked with are unspecified.
 
-   $f1->on_cancel( $f2 )
+   $f1->AWAIT_ON_CANCEL( $f2 )
 
 =cut
 
